# Generated by roxygen2: do not edit by hand

export(check_allowed_values)
export(check_col_count)
export(check_distinct_counts)
export(check_duplicate_rows)
export(check_empty_column)
export(check_inferred_types)
export(check_key_uniqueness)
export(check_min_row_count)
export(check_missing_rate)
export(check_non_numeric)
export(check_numeric_bounds)
export(check_numeric_stats)
export(check_outliers)
export(check_pattern)
export(check_row_count)
export(check_schema_contract)
export(compare_snapshots)
export(detect_files)
export(dq_result)
export(infer_col_type)
export(list_snapshots)
export(load_config)
export(overall_status)
export(read_dataset)
export(read_recent_snapshots)
export(resolve_col_type)
export(run_comparison_checks)
export(run_custom_checks)
export(run_dq_check)
export(run_qc_checks)
importFrom(dplyr,"%>%")
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme_minimal)
importFrom(gridExtra,grid.arrange)
importFrom(kableExtra,cell_spec)
importFrom(kableExtra,kable_styling)
importFrom(kableExtra,kbl)
importFrom(knitr,raw_html)
importFrom(stats,IQR)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(tidyr,pivot_longer)
importFrom(utils,head)
