% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checks_generic.R
\name{check_col_count}
\alias{check_col_count}
\title{QC-05: Report column count}
\usage{
check_col_count(df, config)
}
\description{
QC-05: Report column count
}
\keyword{internal}
