% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checks_generic.R
\name{check_row_count}
\alias{check_row_count}
\title{QC-04: Report row count}
\usage{
check_row_count(df, config)
}
\description{
QC-04: Report row count
}
\keyword{internal}
