% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/snapshot.R
\name{write_snapshot}
\alias{write_snapshot}
\title{Write a run snapshot to the SQLite database}
\usage{
write_snapshot(
  db_path,
  dataset_name,
  file_name,
  df,
  qc_results,
  cp_results,
  custom_results,
  config,
  col_stats = NULL
)
}
\description{
Write a run snapshot to the SQLite database
}
\keyword{internal}
