% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare.R
\name{compare_missing_rate}
\alias{compare_missing_rate}
\title{CP-03: Compare per-column missing rate between deliveries}
\usage{
compare_missing_rate(df_current, df_previous, config)
}
\description{
CP-03: Compare per-column missing rate between deliveries
}
\keyword{internal}
