% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checks_generic.R
\name{.missing_vals}
\alias{.missing_vals}
\title{Test for missing or empty values}
\usage{
.missing_vals(x)
}
\description{
Test for missing or empty values
}
\keyword{internal}
