% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare.R
\name{.missing_rate_vec}
\alias{.missing_rate_vec}
\title{Compute missing rate for a vector}
\usage{
.missing_rate_vec(x)
}
\description{
Compute missing rate for a vector
}
\keyword{internal}
