% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/snapshot.R
\name{init_snapshot_db}
\alias{init_snapshot_db}
\title{Initialise the SQLite snapshot database}
\usage{
init_snapshot_db(db_path)
}
\description{
Initialise the SQLite snapshot database
}
\keyword{internal}
